# PostBillingPreviewRunParamStorageOption

The saving options. The default value is `Csv`.      

## Enum

* `CSV` (value: `'Csv'`)

* `DATABASE` (value: `'Database'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


